==> haskell-quickcheck-classes-0.6.5.0-247-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-7qKr6XNbmiT98ijDuG7okg
key:                  quickcheck-classes-0.6.5.0-7qKr6XNbmiT98ijDuG7okg
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  1fa158ca7f8ec60ac69243882f7c27cf
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-7qKr6XNbmiT98ijDuG7okg
depends:
    QuickCheck-2.14.3-ErwepKtibZRAZpHWEytr6k
    aeson-2.1.2.1-9M5l2yPk4oB5YsVP5y28hb base-4.17.2.1 containers-0.6.7
    primitive-0.8.0.0-AkaLl3oBd0zGZjVVLiSfZ
    primitive-addr-0.1.0.2-EPxKjUyewxrBaeJOdqljO
    quickcheck-classes-base-0.6.2.0-9U2jLvZgl7HJZHtAc0lKTj
    semigroupoids-6.0.1-HPRa1TslLOs3uO6GmX4W3H
    semirings-0.6-JZarONlvZ9GKZqiua6aEbI transformers-0.5.6.2
    vector-0.13.2.0-EmsVweixOBx5SizhJaK3bm

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-classes-0.6.5.0-248-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-3WPSG3WdVT35KLybIKNLyB
key:                  quickcheck-classes-0.6.5.0-3WPSG3WdVT35KLybIKNLyB
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  d148664a3a0f83cb0d3e68b5faecf3e2
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-3WPSG3WdVT35KLybIKNLyB
depends:
    QuickCheck-2.14.3-1OQe8vVNhDx8BJsM0dw2LX
    aeson-2.1.2.1-8bwKrGTS6zMBpBkx7W0Lha base-4.17.2.1 containers-0.6.7
    primitive-0.8.0.0-AkaLl3oBd0zGZjVVLiSfZ
    primitive-addr-0.1.0.2-EPxKjUyewxrBaeJOdqljO
    quickcheck-classes-base-0.6.2.0-zPNbJ3mJkmLFiCHBsXMns
    semigroupoids-6.0.1-L1SyrkGv2pGGclnteZiiwF
    semirings-0.6-9xS4ISvcovw9tVRBgZWBzL transformers-0.5.6.2
    vector-0.13.2.0-CMnyNy925iLU2oFqM6oBU

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
